==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/template/KafkaBridgeTemplateFluent.java <==
package io.strimzi.api.kafka.model.template;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

public interface KafkaBridgeTemplateFluent<A extends KafkaBridgeTemplateFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildDeployment instead.
 * @return The buildable object.
 */
@Deprecated public ResourceTemplate getDeployment();
    public ResourceTemplate buildDeployment();
    public A withDeployment(ResourceTemplate deployment);
    public Boolean hasDeployment();
    public KafkaBridgeTemplateFluent.DeploymentNested<A> withNewDeployment();
    public KafkaBridgeTemplateFluent.DeploymentNested<A> withNewDeploymentLike(ResourceTemplate item);
    public KafkaBridgeTemplateFluent.DeploymentNested<A> editDeployment();
    public KafkaBridgeTemplateFluent.DeploymentNested<A> editOrNewDeployment();
    public KafkaBridgeTemplateFluent.DeploymentNested<A> editOrNewDeploymentLike(ResourceTemplate item);
    
/**
 * This method has been deprecated, please use method buildPod instead.
 * @return The buildable object.
 */
@Deprecated public PodTemplate getPod();
    public PodTemplate buildPod();
    public A withPod(PodTemplate pod);
    public Boolean hasPod();
    public KafkaBridgeTemplateFluent.PodNested<A> withNewPod();
    public KafkaBridgeTemplateFluent.PodNested<A> withNewPodLike(PodTemplate item);
    public KafkaBridgeTemplateFluent.PodNested<A> editPod();
    public KafkaBridgeTemplateFluent.PodNested<A> editOrNewPod();
    public KafkaBridgeTemplateFluent.PodNested<A> editOrNewPodLike(PodTemplate item);
    
/**
 * This method has been deprecated, please use method buildApiService instead.
 * @return The buildable object.
 */
@Deprecated public ResourceTemplate getApiService();
    public ResourceTemplate buildApiService();
    public A withApiService(ResourceTemplate apiService);
    public Boolean hasApiService();
    public KafkaBridgeTemplateFluent.ApiServiceNested<A> withNewApiService();
    public KafkaBridgeTemplateFluent.ApiServiceNested<A> withNewApiServiceLike(ResourceTemplate item);
    public KafkaBridgeTemplateFluent.ApiServiceNested<A> editApiService();
    public KafkaBridgeTemplateFluent.ApiServiceNested<A> editOrNewApiService();
    public KafkaBridgeTemplateFluent.ApiServiceNested<A> editOrNewApiServiceLike(ResourceTemplate item);
    
/**
 * This method has been deprecated, please use method buildPodDisruptionBudget instead.
 * @return The buildable object.
 */
@Deprecated public PodDisruptionBudgetTemplate getPodDisruptionBudget();
    public PodDisruptionBudgetTemplate buildPodDisruptionBudget();
    public A withPodDisruptionBudget(PodDisruptionBudgetTemplate podDisruptionBudget);
    public Boolean hasPodDisruptionBudget();
    public KafkaBridgeTemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudget();
    public KafkaBridgeTemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    public KafkaBridgeTemplateFluent.PodDisruptionBudgetNested<A> editPodDisruptionBudget();
    public KafkaBridgeTemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudget();
    public KafkaBridgeTemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    
/**
 * This method has been deprecated, please use method buildBridgeContainer instead.
 * @return The buildable object.
 */
@Deprecated public ContainerTemplate getBridgeContainer();
    public ContainerTemplate buildBridgeContainer();
    public A withBridgeContainer(ContainerTemplate bridgeContainer);
    public Boolean hasBridgeContainer();
    public KafkaBridgeTemplateFluent.BridgeContainerNested<A> withNewBridgeContainer();
    public KafkaBridgeTemplateFluent.BridgeContainerNested<A> withNewBridgeContainerLike(ContainerTemplate item);
    public KafkaBridgeTemplateFluent.BridgeContainerNested<A> editBridgeContainer();
    public KafkaBridgeTemplateFluent.BridgeContainerNested<A> editOrNewBridgeContainer();
    public KafkaBridgeTemplateFluent.BridgeContainerNested<A> editOrNewBridgeContainerLike(ContainerTemplate item);

    public interface DeploymentNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceTemplateFluent<KafkaBridgeTemplateFluent.DeploymentNested<N>>{

        
    public N and();    public N endDeployment();
}
    public interface PodNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateFluent<KafkaBridgeTemplateFluent.PodNested<N>>{

        
    public N and();    public N endPod();
}
    public interface ApiServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceTemplateFluent<KafkaBridgeTemplateFluent.ApiServiceNested<N>>{

        
    public N and();    public N endApiService();
}
    public interface PodDisruptionBudgetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodDisruptionBudgetTemplateFluent<KafkaBridgeTemplateFluent.PodDisruptionBudgetNested<N>>{

        
    public N and();    public N endPodDisruptionBudget();
}
    public interface BridgeContainerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ContainerTemplateFluent<KafkaBridgeTemplateFluent.BridgeContainerNested<N>>{

        
    public N and();    public N endBridgeContainer();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/template/KafkaBridgeTemplateFluent.java <==
package io.strimzi.api.kafka.model.template;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

public interface KafkaBridgeTemplateFluent<A extends KafkaBridgeTemplateFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildDeployment instead.
 * @return The buildable object.
 */
@Deprecated public DeploymentTemplate getDeployment();
    public DeploymentTemplate buildDeployment();
    public A withDeployment(DeploymentTemplate deployment);
    public Boolean hasDeployment();
    public KafkaBridgeTemplateFluent.DeploymentNested<A> withNewDeployment();
    public KafkaBridgeTemplateFluent.DeploymentNested<A> withNewDeploymentLike(DeploymentTemplate item);
    public KafkaBridgeTemplateFluent.DeploymentNested<A> editDeployment();
    public KafkaBridgeTemplateFluent.DeploymentNested<A> editOrNewDeployment();
    public KafkaBridgeTemplateFluent.DeploymentNested<A> editOrNewDeploymentLike(DeploymentTemplate item);
    
/**
 * This method has been deprecated, please use method buildPod instead.
 * @return The buildable object.
 */
@Deprecated public PodTemplate getPod();
    public PodTemplate buildPod();
    public A withPod(PodTemplate pod);
    public Boolean hasPod();
    public KafkaBridgeTemplateFluent.PodNested<A> withNewPod();
    public KafkaBridgeTemplateFluent.PodNested<A> withNewPodLike(PodTemplate item);
    public KafkaBridgeTemplateFluent.PodNested<A> editPod();
    public KafkaBridgeTemplateFluent.PodNested<A> editOrNewPod();
    public KafkaBridgeTemplateFluent.PodNested<A> editOrNewPodLike(PodTemplate item);
    
/**
 * This method has been deprecated, please use method buildApiService instead.
 * @return The buildable object.
 */
@Deprecated public ResourceTemplate getApiService();
    public ResourceTemplate buildApiService();
    public A withApiService(ResourceTemplate apiService);
    public Boolean hasApiService();
    public KafkaBridgeTemplateFluent.ApiServiceNested<A> withNewApiService();
    public KafkaBridgeTemplateFluent.ApiServiceNested<A> withNewApiServiceLike(ResourceTemplate item);
    public KafkaBridgeTemplateFluent.ApiServiceNested<A> editApiService();
    public KafkaBridgeTemplateFluent.ApiServiceNested<A> editOrNewApiService();
    public KafkaBridgeTemplateFluent.ApiServiceNested<A> editOrNewApiServiceLike(ResourceTemplate item);
    
/**
 * This method has been deprecated, please use method buildPodDisruptionBudget instead.
 * @return The buildable object.
 */
@Deprecated public PodDisruptionBudgetTemplate getPodDisruptionBudget();
    public PodDisruptionBudgetTemplate buildPodDisruptionBudget();
    public A withPodDisruptionBudget(PodDisruptionBudgetTemplate podDisruptionBudget);
    public Boolean hasPodDisruptionBudget();
    public KafkaBridgeTemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudget();
    public KafkaBridgeTemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    public KafkaBridgeTemplateFluent.PodDisruptionBudgetNested<A> editPodDisruptionBudget();
    public KafkaBridgeTemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudget();
    public KafkaBridgeTemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    
/**
 * This method has been deprecated, please use method buildBridgeContainer instead.
 * @return The buildable object.
 */
@Deprecated public ContainerTemplate getBridgeContainer();
    public ContainerTemplate buildBridgeContainer();
    public A withBridgeContainer(ContainerTemplate bridgeContainer);
    public Boolean hasBridgeContainer();
    public KafkaBridgeTemplateFluent.BridgeContainerNested<A> withNewBridgeContainer();
    public KafkaBridgeTemplateFluent.BridgeContainerNested<A> withNewBridgeContainerLike(ContainerTemplate item);
    public KafkaBridgeTemplateFluent.BridgeContainerNested<A> editBridgeContainer();
    public KafkaBridgeTemplateFluent.BridgeContainerNested<A> editOrNewBridgeContainer();
    public KafkaBridgeTemplateFluent.BridgeContainerNested<A> editOrNewBridgeContainerLike(ContainerTemplate item);

    public interface DeploymentNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DeploymentTemplateFluent<KafkaBridgeTemplateFluent.DeploymentNested<N>>{

        
    public N and();    public N endDeployment();
}
    public interface PodNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateFluent<KafkaBridgeTemplateFluent.PodNested<N>>{

        
    public N and();    public N endPod();
}
    public interface ApiServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceTemplateFluent<KafkaBridgeTemplateFluent.ApiServiceNested<N>>{

        
    public N and();    public N endApiService();
}
    public interface PodDisruptionBudgetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodDisruptionBudgetTemplateFluent<KafkaBridgeTemplateFluent.PodDisruptionBudgetNested<N>>{

        
    public N and();    public N endPodDisruptionBudget();
}
    public interface BridgeContainerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ContainerTemplateFluent<KafkaBridgeTemplateFluent.BridgeContainerNested<N>>{

        
    public N and();    public N endBridgeContainer();
}


}
